@@ -92,6 +92,7 @@ private:
 		result.push_back(&options.environment);
 		result.push_back(&options.baseURI);
 		result.push_back(&options.spawnMethod);
+		result.push_back(&options.bindAddress);
 
 		result.push_back(&options.user);
 		result.push_back(&options.group);
@@ -115,6 +116,8 @@ private:
 		result.push_back(&options.hostName);
 		result.push_back(&options.uri);
 
+		result.push_back(&options.stickySessionsCookieAttributes);
+
 		return result;
 	}
 
@@ -228,6 +231,12 @@ public:
 	 */
 	StaticString spawnMethod;
 
+	/**
+	 * The address that Passenger binds to in order to allow sending HTTP
+	 * requests to individual application processes.
+	 */
+	StaticString bindAddress;
+
 	/** See overview. */
 	StaticString user;
 	/** See class overview. */
@@ -303,6 +312,10 @@ public:
 	 */
 	bool loadShellEnvvars;
 
+	/** Whether to tell Ruby to load bundler during spawning.
+	 */
+	bool preloadBundler;
+
 	bool userSwitching;
 
 	/**
@@ -353,6 +366,12 @@ public:
 	 */
 	bool abortWebsocketsOnProcessShutdown;
 
+	/**
+	 * The attributes to use for the sticky session cookie.
+	 * Values should validate against the regex: ([\w]+(=[\w]+)?; )*
+	 */
+	StaticString stickySessionsCookieAttributes;
+
 	/*-----------------*/
 
 
@@ -434,6 +453,7 @@ public:
 		  environment(DEFAULT_APP_ENV, sizeof(DEFAULT_APP_ENV) - 1),
 		  baseURI("/", 1),
 		  spawnMethod(DEFAULT_SPAWN_METHOD, sizeof(DEFAULT_SPAWN_METHOD) - 1),
+		  bindAddress(DEFAULT_BIND_ADDRESS, sizeof(DEFAULT_BIND_ADDRESS) - 1),
 		  defaultUser(PASSENGER_DEFAULT_USER, sizeof(PASSENGER_DEFAULT_USER) - 1),
 		  lveMinUid(DEFAULT_LVE_MIN_UID),
 		  integrationMode(DEFAULT_INTEGRATION_MODE, sizeof(DEFAULT_INTEGRATION_MODE) - 1),
@@ -444,6 +464,7 @@ public:
 		  forceMaxConcurrentRequestsPerProcess(-1),
 		  debugger(false),
 		  loadShellEnvvars(true),
+		  preloadBundler(false),
 		  userSwitching(true),
 		  raiseInternalError(false),
 
@@ -453,6 +474,7 @@ public:
 		  maxOutOfBandWorkInstances(1),
 		  maxRequestQueueSize(DEFAULT_MAX_REQUEST_QUEUE_SIZE),
 		  abortWebsocketsOnProcessShutdown(true),
+		  stickySessionsCookieAttributes(DEFAULT_STICKY_SESSIONS_COOKIE_ATTRIBUTES, sizeof(DEFAULT_STICKY_SESSIONS_COOKIE_ATTRIBUTES) - 1),
 
 		  stickySessionId(0),
 		  statThrottleRate(DEFAULT_STAT_THROTTLE_RATE),
@@ -560,6 +582,7 @@ public:
 			appendKeyValue (vec, "environment",        environment);
 			appendKeyValue (vec, "base_uri",           baseURI);
 			appendKeyValue (vec, "spawn_method",       spawnMethod);
+			appendKeyValue (vec, "bind_address",       bindAddress);
 			appendKeyValue (vec, "user",               user);
 			appendKeyValue (vec, "group",              group);
 			appendKeyValue (vec, "default_user",       defaultUser);
@@ -582,6 +605,7 @@ public:
 			appendKeyValue3(vec, "max_processes",       maxProcesses);
 			appendKeyValue2(vec, "max_preloader_idle_time", maxPreloaderIdleTime);
 			appendKeyValue3(vec, "max_out_of_band_work_instances", maxOutOfBandWorkInstances);
+			appendKeyValue (vec, "sticky_sessions_cookie_attributes", stickySessionsCookieAttributes);
 		}
 
 		/*********************************/
@@ -652,9 +676,9 @@ public:
 	StaticString getProcessTitle(const WrapperRegistry::Registry &registry) const {
 		const WrapperRegistry::Entry &entry = registry.lookup(appType);
 		if (entry.isNull()) {
-			return entry.processTitle;
-		} else {
 			return StaticString();
+		} else {
+			return entry.processTitle;
 		}
 	}
 
